<?php
/*
Plugin Name: Reactor Core
Plugin URI: http://www.theme-reactor.com
Description: ThemeReactor Core Plugin for ThemeReactor Themes
Version: 1.3.1
Author: ThemeReactor
Author URI: http://www.theme-reactor.com
*/

class ReactorShortcodes {

	function __construct()
	{
		require_once( 'shortcodes.php' );
		define('REACTOR_TINYMCE_URI', get_template_directory_uri() . '/library/inc/shortcodes/tinymce');
		define('REACTOR_TINYMCE_DIR', get_template_directory() . '/library/inc/shortcodes/tinymce');

		add_action('init', array(&$this, 'init'));
		add_action('admin_init', array(&$this, 'admin_init'));
		add_action('wp_ajax_reactor_shortcodes_popup', array(&$this, 'popup'));
	}

	/**
	 * Registers TinyMCE rich editor buttons
	 *
	 * @return	void
	 */
	function init()
	{
		/*if( ! is_admin() )
		{
			wp_enqueue_style( 'reactor-shortcodes', plugin_dir_url( __FILE__ ) . 'shortcodes.css' );
			wp_enqueue_script( 'jquery-ui-accordion' );
			wp_enqueue_script( 'jquery-ui-tabs' );
			wp_enqueue_script( 'reactor-shortcodes-lib', plugin_dir_url( __FILE__ ) . 'js/reactor-shortcodes-lib.js', array('jquery', 'jquery-ui-accordion', 'jquery-ui-tabs') );
		}*/

		if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') )
			return;

		if ( get_user_option('rich_editing') == 'true' )
		{
			add_filter( 'mce_external_plugins', array(&$this, 'add_rich_plugins') );
			add_filter( 'mce_buttons', array(&$this, 'register_rich_buttons') );
		}

	}

	// --------------------------------------------------------------------------

	/**
	 * Defins TinyMCE rich editor js plugin
	 *
	 * @return	void
	 */
	function add_rich_plugins( $plugin_array )
	{
		if( is_admin() ) {
			$plugin_array['reactor_button'] = REACTOR_TINYMCE_URI . '/plugin.js';
		}

		return $plugin_array;
	}

	// --------------------------------------------------------------------------

	/**
	 * Adds TinyMCE rich editor buttons
	 *
	 * @return	void
	 */
	function register_rich_buttons( $buttons )
	{
		array_push( $buttons, 'reactor_button' );
		return $buttons;
	}

	/**
	 * Enqueue Scripts and Styles
	 *
	 * @return	void
	 */
	function admin_init()
	{
		// css
		wp_enqueue_style( 'reactor-popup', REACTOR_TINYMCE_URI . '/css/popup.css', false, '1.0', 'all' );
		wp_enqueue_style( 'jquery.chosen', REACTOR_TINYMCE_URI . '/css/chosen.css', false, '1.0', 'all' );

		// js
		wp_enqueue_script( 'jquery-ui-sortable' );
		wp_enqueue_script( 'jquery-livequery', REACTOR_TINYMCE_URI . '/js/jquery.livequery.js', false, '1.1.1', false );
		wp_enqueue_script( 'jquery-appendo', REACTOR_TINYMCE_URI . '/js/jquery.appendo.js', false, '1.0', false );
		wp_enqueue_script( 'jquery.chosen', REACTOR_TINYMCE_URI . '/js/chosen.jquery.min.js', false, '1.0', false );
		wp_enqueue_script( 'reactor-popup', REACTOR_TINYMCE_URI . '/js/popup.js', false, '1.0', false );

		// Developer mode
		$dev_mode = current_theme_supports( 'reactor_shortcodes_embed' );
		if( $dev_mode ) {
			$dev_mode = 'true';
		} else {
			$dev_mode = 'false';
		}

		wp_localize_script( 'jquery', 'ReactorShortcodes', array('plugin_folder' => get_template_directory_uri() . '/library/inc/shortcodes/', 'Presentation' => $dev_mode) );
	}

	/**
	 * Popup function which will show shortcode options in thickbox.
	 *
	 * @return void
	 */
	function popup() {

		require_once( REACTOR_TINYMCE_DIR . '/reactor-sc.php' );

		die();

	}

}
$reactor_shortcodes_obj = new ReactorShortcodes();